import VerificationError from "./services/VerificationService/VerificationError";
export interface Participant {
    name: string;
    email: string;
}
export interface Attachment {
    name: string;
    url?: string;
    size: number;
    hash: string;
    hashAlg: string;
    signature: string;
}
export interface IpfsContentData {
    cid: string;
    key: string;
    head: string;
}
export interface IpfsAttachmentData {
    cid: string;
    key: string;
    contentHash: string;
    head: string;
    contentType: string;
}
export declare type IpfsDataVersion = undefined | "v2";
export interface IpfsData {
    version: IpfsDataVersion;
    plaintText: IpfsContentData;
    html: IpfsContentData;
    attachments: Array<IpfsAttachmentData>;
}
export interface MessageData {
    sender: Participant;
    subject: string;
    date: string;
    recipients: {
        to: Array<Participant>;
        cc?: Array<Participant>;
    };
    attachments: Array<Attachment>;
    senderPublicKeyUuid: string;
    ipfs?: IpfsData;
}
export interface StatusData {
    status?: StatusObject;
    statusRaw: string;
    statusClassName?: string;
    batchId: string;
    transactionHash: string;
    timestamp: number;
}
export interface BatchVerificationDetails {
    statusPosition: number;
    batchSize: number;
    verified: boolean;
    batchHash: string;
}
export interface StatusesBatchData {
    verificationMethod: string;
    hash: string;
    items: Array<string>;
}
export interface VerificationData {
    statusData?: StatusData;
    blockData?: BlockData;
    txData?: TxData;
    batchVerificationDetails?: BatchVerificationDetails;
    verificationError?: VerificationError;
}
export interface BlockData {
    blockHeight: number;
    timestamp: number;
    confirmationsAmount: number;
}
export interface TxData {
    hash: string;
    blockHeight: number;
    blockHash: string;
    tx: {
        callData: string;
    };
    time?: number;
}
export interface DecodedCallData {
    key: string;
    value: string;
}
export interface AttachmentSignature {
    value: string;
    preSignHashAlgorithm: string;
}
export interface SenderStatusObject {
    signatureTime: number;
    signatureTimeSignature: string;
    messageSignature?: string;
    attachmentsSignatures: {
        [key: string]: {
            list: AttachmentSignature[];
        };
    };
    messageSignatureHashingAlgorithm: string;
    senderSystem: string;
    sealHash?: string;
    sealSignature?: string;
    htmlPartsSignature?: string;
    plainPartsSignature?: string;
    pseudoPlainPartsSignature?: string;
}
export interface RecipientStatusObjectData {
    creationDate: number;
    gatewayDomainHash: string;
    randomToken: string;
    emailHash: string;
}
export interface RecipientStatusObject {
    iv: string;
    encryptedContent: string;
    decryptors: {
        [key: string]: string;
    };
}
export interface WrapperData {
    data: string | ArrayBuffer;
    version: number;
    className: string;
}
export interface QrCodeData {
    encryptedKey: Uint8Array;
    encryptedData: Uint8Array;
    nonce: Uint8Array;
}
export declare type StatusObject = SenderStatusObject | RecipientStatusObject;
export interface KeyDataPair {
    key: string;
    data: string;
}
